some tweaks, nothing major

Kev
Index: CollectionUtils.java
===================================================================
RCS file: 
/home/cvspublic/ant/src/main/org/apache/tools/ant/util/CollectionUtils.java,v
retrieving revision 1.18
diff -u -r1.18 CollectionUtils.java
--- CollectionUtils.java        14 Mar 2005 09:14:56 -0000      1.18
+++ CollectionUtils.java        12 Apr 2005 07:13:47 -0000
@@ -191,11 +191,8 @@
         public Object nextElement() throws NoSuchElementException {
             if (e1.hasMoreElements()) {
                 return e1.nextElement();
-            } else {
-                return e2.nextElement();
-            }
+            } 
+            return e2.nextElement();
         }
-
     }
-
 }
Index: ContainerMapper.java
===================================================================
RCS file: 
/home/cvspublic/ant/src/main/org/apache/tools/ant/util/ContainerMapper.java,v
retrieving revision 1.5
diff -u -r1.5 ContainerMapper.java
--- ContainerMapper.java        24 Jan 2005 18:13:20 -0000      1.5
+++ ContainerMapper.java        12 Apr 2005 07:13:48 -0000
@@ -25,7 +25,7 @@
 
 /**
  * A <code>FileNameMapper</code> that contains
- * other <CODE>FileNameMapper</CODE>s.
+ * other <code>FileNameMapper</code>s.
  * @see FileNameMapper
  */
 public abstract class ContainerMapper implements FileNameMapper {
@@ -42,11 +42,11 @@
 
     /**
      * Add a <code>FileNameMapper</code>.
-     * @param fileNameMapper a <CODE>FileNameMapper</CODE>.
+     * @param fileNameMapper a <code>FileNameMapper</code>.
      * @throws IllegalArgumentException if attempting to add this
-     *         <CODE>ContainerMapper</CODE> to itself, or if the specified
-     *         <CODE>FileNameMapper</CODE> is itself a 
<CODE>ContainerMapper</CODE>
-     *         that contains this <CODE>ContainerMapper</CODE>.
+     *         <code>ContainerMapper</code> to itself, or if the specified
+     *         <code>FileNameMapper</code> is itself a 
<code>ContainerMapper</code>
+     *         that contains this <code>ContainerMapper</code>.
      */
     public synchronized void add(FileNameMapper fileNameMapper) {
         if (this == fileNameMapper
@@ -60,10 +60,10 @@
     }
 
     /**
-     * Return <CODE>true</CODE> if this <CODE>ContainerMapper</CODE> or any of
-     * its sub-elements contains the specified <CODE>FileNameMapper</CODE>.
-     * @param fileNameMapper   the <CODE>FileNameMapper</CODE> to search for.
-     * @return <CODE>boolean</CODE>.
+     * Return <code>true</code> if this <code>ContainerMapper</code> or any of
+     * its sub-elements contains the specified <code>FileNameMapper</code>.
+     * @param fileNameMapper   the <code>FileNameMapper</code> to search for.
+     * @return <code>boolean</code>.
      */
     protected synchronized boolean contains(FileNameMapper fileNameMapper) {
         boolean foundit = false;
@@ -77,8 +77,8 @@
     }
 
     /**
-     * Get the <CODE>List</CODE> of <CODE>FileNameMapper</CODE>s.
-     * @return <CODE>List</CODE>.
+     * Get the <code>List</code> of <code>FileNameMapper</code>s.
+     * @return <code>List</code>.
      */
     public synchronized List getMappers() {
         return Collections.unmodifiableList(mappers);
Index: FileUtils.java
===================================================================
RCS file: 
/home/cvspublic/ant/src/main/org/apache/tools/ant/util/FileUtils.java,v
retrieving revision 1.93
diff -u -r1.93 FileUtils.java
--- FileUtils.java      7 Apr 2005 23:42:46 -0000       1.93
+++ FileUtils.java      12 Apr 2005 07:13:57 -0000
@@ -891,9 +891,8 @@
             index = path.indexOf(File.separatorChar, 1);
             if (index == -1) {
                 return path.substring(1) + ":[000000]";
-            } else {
-                device = path.substring(1, index++);
             }
+            device = path.substring(1, index++);
         }
         if (isDirectory) {
             directory = new StringBuffer(path.substring(index).
Index: SourceFileScanner.java
===================================================================
RCS file: 
/home/cvspublic/ant/src/main/org/apache/tools/ant/util/SourceFileScanner.java,v
retrieving revision 1.30
diff -u -r1.30 SourceFileScanner.java
--- SourceFileScanner.java      24 Jan 2005 22:08:32 -0000      1.30
+++ SourceFileScanner.java      12 Apr 2005 07:13:58 -0000
@@ -37,7 +37,7 @@
     protected Task task;
 
     private static final FileUtils FILE_UTILS = FileUtils.getFileUtils();
-    private File destDir;     // base directory of the fileset
+    private File baseDir;     // base directory of the fileset
 
     /**
      * Construct a new SourceFileScanner.
@@ -84,7 +84,7 @@
     public String[] restrict(String[] files, File srcDir, File destDir,
                              FileNameMapper mapper, long granularity) {
         // record destdir for later use in getResource
-        this.destDir = destDir;
+        this.baseDir = destDir;
         Vector v = new Vector();
         for (int i = 0; i < files.length; i++) {
             File src = FILE_UTILS.resolveFile(srcDir, files[i]);
@@ -153,12 +153,12 @@
     /**
      * Returns resource information for a file at destination.
      * @param name relative path of file at destination.
      * @return data concerning a file whose relative path to destDir is name.
      *
      * @since Ant 1.5.2
      */
     public Resource getResource(String name) {
-        File src = FILE_UTILS.resolveFile(destDir, name);
+        File src = FILE_UTILS.resolveFile(baseDir, name);
         return new Resource(name, src.exists(), src.lastModified(),
                             src.isDirectory());
     }

---------------------------------------------------------------------
@@ -153,12 +153,12 @@
      * Returns resource information for a file at destination.
      * @param name relative path of file at destination.
-     * @return data concerning a file whose relative path to destDir is name.
+     * @return data concerning a file whose relative path to baseDir is name.
      *
      * @since Ant 1.5.2
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]

Reply via email to